@@ -58,7 +58,7 @@ encoder = keras.models.Model(bert.model.inputs, bert.model.outputs[0])
 maxlen = 64
 
 
-@lru_cache(10000)
+@lru_cache(100000)
 def text2vec(text):
     token_ids, segment_ids = tokenizer.encode(text, maxlen=maxlen)
     data = [sequence_padding([token_ids], length=maxlen), sequence_padding([segment_ids], length=maxlen)]
@@ -78,25 +78,38 @@ def texts2vec(texts):
     return vecs
 
 
+# def get_one_vec(**kwargs):
+#     text = kwargs.get('text', '默认')
+#     is_lite = kwargs.get('is_lite', '0')
+#
+#     doc = cache_bert.find_one({'text': text})
+#
+#     if doc:
+#         logger.info(f'dup key: {text}')
+#         vecs = doc['vector']
+#     else:
+#         vecs = text2vec(text)
+#         vecs = normalize(vecs).tolist()
+#
+#         cache_bert.insert_one({'text': text, 'vector': vecs})
+#
+#     if is_lite == '0':
+#         return vecs
+#     else:
+#         vecs = np.array(vecs)[:, range(0, 768, 4)]
+#         return normalize(vecs).tolist()  # 64*3 = 192维度
+
 def get_one_vec(**kwargs):
     text = kwargs.get('text', '默认')
     is_lite = kwargs.get('is_lite', '0')
 
-    doc = cache_bert.find_one({'text': text})
-
-    if doc:
-        logger.info(f'dup key: {text}')
-        vecs = doc['vector']
-    else:
-        vecs = text2vec(text)
-        vecs = normalize(vecs).tolist()
-
-        cache_bert.insert_one({'text': text, 'vector': vecs})
+    vecs = text2vec(text)
+    vecs = normalize(vecs)
 
     if is_lite == '0':
-        return vecs
+        return vecs.tolist()
     else:
-        vecs = np.array(vecs)[:, range(0, 768, 4)]
+        vecs = vecs[:, range(0, 768, 4)]
         return normalize(vecs).tolist()  # 64*3 = 192维度
 
 
